@@ -10,6 +10,7 @@
 # green = user entry, yellow = correct entry
 #' @importFrom crayon green
 #' @importFrom crayon yellow
+#' @importFrom crayon italic
 
 
 # ------------------------------------------------------------------------------
@@ -19,3 +20,13 @@ glue_stop <- function(..., .sep = "") {
   msg <- glue::glue(..., .sep, .envir = parent.frame())
   stop(msg, call. = FALSE)
 }
+
+validate_not_all_null <- function(x) {
+  all_null <- all(purrr::map_lgl(x, is.null))
+
+  if (all_null) {
+    glue_stop("All tickers failed to download any data. Aborting.")
+  }
+
+  invisible(x)
+}
